==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/Q3ExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { Q3ExpressionDescription } from "./Q3ExpressionDescription";
/**
 * @hidden
 */
export let Q3ExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class Q3ExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (Q3ExpressionDescriptionMetadata.a == null) {
                Q3ExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                Q3ExpressionDescriptionMetadata.c(Q3ExpressionDescriptionMetadata.a);
            }
            if (a.j(Q3ExpressionDescriptionMetadata.a)) {
                return;
            }
            a.y(Q3ExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            Q3ExpressionDescriptionMetadata.b(a);
            a.aa("Q3Expression", () => new Q3ExpressionDescription());
            a.z("Q3Expression", Q3ExpressionDescriptionMetadata.a);
        }
    }
    Q3ExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(Q3ExpressionDescriptionMetadata, 'Q3ExpressionDescriptionMetadata');
    Q3ExpressionDescriptionMetadata.a = null;
    return Q3ExpressionDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/Q3ExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WrapperExpressionDescriptionMetadata } from "./WrapperExpressionDescriptionMetadata";
import { Q3ExpressionDescription } from "./Q3ExpressionDescription";
/**
 * @hidden
 */
export let Q3ExpressionDescriptionMetadata = /*@__PURE__*/ (() => {
    class Q3ExpressionDescriptionMetadata extends Base {
        static b(a) {
            if (Q3ExpressionDescriptionMetadata.a == null) {
                Q3ExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                Q3ExpressionDescriptionMetadata.c(Q3ExpressionDescriptionMetadata.a);
            }
            if (a.k(Q3ExpressionDescriptionMetadata.a)) {
                return;
            }
            a.aa(Q3ExpressionDescriptionMetadata.a);
        }
        static c(a) {
            WrapperExpressionDescriptionMetadata.c(a);
        }
        static d(a) {
            Q3ExpressionDescriptionMetadata.b(a);
            a.ac("Q3Expression", () => new Q3ExpressionDescription());
            a.ab("Q3Expression", Q3ExpressionDescriptionMetadata.a);
        }
    }
    Q3ExpressionDescriptionMetadata.$t = /*@__PURE__*/ markType(Q3ExpressionDescriptionMetadata, 'Q3ExpressionDescriptionMetadata');
    Q3ExpressionDescriptionMetadata.a = null;
    return Q3ExpressionDescriptionMetadata;
})();
